@@ -3,17 +3,17 @@
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
-#include <MauiKit3/Core/mauiandroid.h>
+#include <MauiKit4/Core/mauiandroid.h>
 #else
 #include <QApplication>
 #endif
 
-#include <MauiKit3/Core/mauiapp.h>
-#include <MauiKit3/TextEditor/moduleinfo.h>
+#include <MauiKit4/Core/mauiapp.h>
+#include <MauiKit4/TextEditor/moduleinfo.h>
 
 #include "nota.h"
 #include "../nota_version.h"
@@ -27,9 +27,6 @@
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
     if (!MAUIAndroid::checkRunTimePermissions({"android.permission.WRITE_EXTERNAL_STORAGE"}))
@@ -101,7 +98,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     auto server = std::make_unique<Server>();
 
     QQmlApplicationEngine engine;
-    const QUrl url(QStringLiteral("qrc:/main.qml"));
+    const QUrl url(QStringLiteral("qrc:/app/maui/nota/main.qml"));
     QObject::connect(
                 &engine,
                 &QQmlApplicationEngine::objectCreated,
